%% CODE TO PERFORM ADDITIONAL QC MRS ANALYSIS REQUIRED IN 1ST ROUND REV

% This code extracts QC MRS metric (linewidth, CRLB and SNR across
% participants)

% It needs;
% a "your_paths.txt" file with all the info on your paths. An example is
% provided on GIT + the fitted MRS data.
%-----------------------------------------------------------------------
% Written by I. Paparella
% Cyclotron Research Centre, University of Liege, Belgium
% 06th November 2024

%% Path info
paths_txt = fileread('your_paths.txt') ;
paths_txt = char(strsplit(paths_txt, '\n')) ;

pathtodata = (strtrim(paths_txt(2,:)));

%%  Select the subject to analyse (all except 001, 007 and 011 which are males)
cd(pathtodata);
[subdir] = spm_select(Inf,'dir','Select subject_ID directory');
IDs = str2num(subdir(:,end-2:end));

%% Variables needed
%Metrics= ['SNR', 'FWHM', '%CRLB'];
Metabs ={'GABA', 'NAA', 'Cr'};
%% Initalize variables
%MRS_QC_metrics = zeros(size(subdir,1),(length(Metrics)*length(Metabs)));
MRS_QC_metrics = [];
%% Loop across subjects to analyse and get subjective parameters
for isub = 1:size(subdir,1)
    
    % Extract path info per subject
    subject_ID = sprintf('sub-%03d', IDs(isub));
    subject_MRSfit = fullfile (pathtodata, subject_ID, 'MRS');
    
    % Load .csv summary table
    SubMRS= readtable(fullfile(subject_MRSfit, '/summary.csv'));
    SubMRS.Metab = categorical(SubMRS.Metab); %convert to categorical
    
    % Extract needed info
    MRS_QC_metrics_Sbj = [];
    for metabi= 1: length(Metabs)
        MRS_QC_metrics_Sbj= [MRS_QC_metrics_Sbj table2array(SubMRS(SubMRS.Metab== Metabs(metabi), end-2:end))];
    end
    MRS_QC_metrics = [MRS_QC_metrics; MRS_QC_metrics_Sbj];
end

MRS_QC_metrics=array2table(MRS_QC_metrics);
IDs_table = table(IDs);

MRS_QC_metrics_full = [IDs_table MRS_QC_metrics];

MRS_QC_metrics_full.Properties.VariableNames = {'Sbj_number'; 'GABA_CRLB'; 'GABA_SNR';'GABA_FWHM';...
    'NAA_CRLB'; 'NAA_SNR';'NAA_FWHM';'Cr_CRLB'; 'Cr_SNR';'Cr_FWHM'};
writetable(MRS_QC_metrics_full,fullfile(pathtodata,'MRS_QC_1stRev_AllFemale.csv'),'WriteRowNames',true);